@@ -1,16 +1,19 @@
 from enum import Enum
-from . import nh, fanfox, mangadex
+from . import NHentai, Fanfox, Mangadex, NaverWebtoon, NaverBestChallenge, NaverChallenge
 from ..excepts import FetcherNotFound
 
 
-class Fetchers(Enum):
+class FetcherEnum(Enum):
 	__doc__ = """
 	Enumeration of all the fetchers available to the program at the moment
 	"""
 
-	NHENTAI = nh.NHentai
-	FANFOX = fanfox.Fanfox
-	MANGADEX = mangadex.Mangadex
+	NHENTAI = NHentai
+	FANFOX = Fanfox
+	MANGADEX = Mangadex
+	NAVERWEBTOON = NaverWebtoon
+	NAVERBESTCHALLENGE = NaverBestChallenge
+	NAVERCHALLENGE = NaverChallenge
 
 	@classmethod
 	def get(cls, fetcher_name_request: str):
